public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] cs5535-clockevt: typo, it's MFGPT, not MFPGT
@ 2012-07-04 12:22 Jens Rottmann
  0 siblings, 0 replies; only message in thread
From: Jens Rottmann @ 2012-07-04 12:22 UTC (permalink / raw)
  To: Thomas Gleixner; +Cc: John Stultz, linux-kernel

cs5535-clockevt: typo, it's MFGPT, not MFPGT

Had me fooled for a while, "dmesg|grep -i mfgpt" wouldn't show anything.

Signed-off-by: Jens Rottmann <JRottmann@LiPPERTEmbedded.de>
---

--- linux-3.4/drivers/clocksource/cs5535-clockevt.c
+++ mfgpt_typo/drivers/clocksource/cs5535-clockevt.c
@@ -53,7 +53,7 @@
 #define MFGPT_PERIODIC (MFGPT_HZ / HZ)
 
 /*
  * The MFPGT timers on the CS5536 provide us with suitable timers to use
  * as clock event sources - not as good as a HPET or APIC, but certainly
  * better than the PIT.  This isn't a general purpose MFGPT driver, but
  * a simplified one designed specifically to act as a clock event source.
@@ -144,7 +144,7 @@
 
 	timer = cs5535_mfgpt_alloc_timer(MFGPT_TIMER_ANY, MFGPT_DOMAIN_WORKING);
 	if (!timer) {
-		printk(KERN_ERR DRV_NAME ": Could not allocate MFPGT timer\n");
+		printk(KERN_ERR DRV_NAME ": Could not allocate MFGPT timer\n");
 		return -ENODEV;
 	}
 	cs5535_event_clock = timer;
_

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2012-07-04 12:38 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -53,7 +53,7 @@
 
 /*
- * The MFPGT timers on the CS5536 provide us with suitable timers to use
+ * The MFGPT timers on the CS5536 provide us with suitable timers to use
  * as clock event sources - not as good as a HPET or APIC, but certainly
  * better than the PIT.  This isn't a general purpose MFGPT driver, but
2012-07-04 12:22 [PATCH] cs5535-clockevt: typo, it's MFGPT, not MFPGT Jens Rottmann

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox